@@ -5,7 +5,7 @@ support.
 __author__ = 'Gavin M. Roy'
 __email__ = 'gmr@meetme.com'
 __since__ = '2012-04-11'
-__version__ = '1.4.2'
+__version__ = '1.4.3'
 
 import daemon
 import grp
@@ -682,7 +682,7 @@ def run(controller, option_callback=None):
             return process.run()
         except KeyboardInterrupt:
             logger.info('CTRL-C caught, shutting down')
-            process._on_sigterm()
+            process._shutdown()
             return
 
     # Run the process with the daemon context
